==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/doc/doxygen-pages/env-vars.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

/** \page env-vars Environment variables that MRPT looks for
 *

The following environment variables may be set to alter some MRPT functionality:

- <code>MRPT_WXSUBSYS_TIMEOUT_MS</code>: The timeout in milliseconds to wait 
  in mrpt::gui windows constructors until the wxWidgets thread processes and 
  really creates the window, before reporting an error. It's also used in 
  the function mrpt::hwdrivers::prepareVideoSourceFromUserSelection(). 
  Default: "5000" in Release builds, "30000" in Debug. 

- <code>MRPT_HWDRIVERS_VERBOSE</code>: Set to "1" to enable verbose output to cout
   from all mrpt::hwdrivers classes. Default: "0".

- <code>MRPT_CCAMERA_KINECT_TIMEOUT_MS</code>: Timeout in milliseconds to wait
   for a new frame from a Kinect sensor when using the method 
   mrpt::hwdrivers::CCamera::getNextFrame(). Default: "3000".
   

*/

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/doc/doxygen-pages/env-vars.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

/** \page env-vars Environment variables that MRPT looks for
 *

The following environment variables may be set to alter some MRPT functionality:

- <code>MRPT_WXSUBSYS_TIMEOUT_MS</code>: The timeout in milliseconds to wait 
  in mrpt::gui windows constructors until the wxWidgets thread processes and 
  really creates the window, before reporting an error. It's also used in 
  the function mrpt::hwdrivers::prepareVideoSourceFromUserSelection(). 
  Default: "5000" in Release builds, "30000" in Debug. 

- <code>MRPT_HWDRIVERS_VERBOSE</code>: Set to "1" to enable verbose output to cout
   from all mrpt::hwdrivers classes. Default: "0".

- <code>MRPT_CCAMERA_KINECT_TIMEOUT_MS</code>: Timeout in milliseconds to wait
   for a new frame from a Kinect sensor when using the method 
   mrpt::hwdrivers::CCamera::getNextFrame(). Default: "3000".
   

*/
